@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::MSCHOUT;
 BEGIN {
-  $Dist::Zilla::PluginBundle::MSCHOUT::VERSION = '0.13';
+  $Dist::Zilla::PluginBundle::MSCHOUT::VERSION = '0.14';
 }
 
 # ABSTRACT: Use L<Dist::Zilla> like MSCHOUT does
@@ -17,9 +17,16 @@ sub configure {
 
     my $upload = $$args{no_upload} ? 0 : 1;
 
+    my @remove = qw(PodVersion);
+
+    # if not uploading, remove the upload plugin, and the confirmation plugin
+    unless ($upload) {
+        push @remove, 'UploadToCPAN', 'ConfirmRelease';
+    }
+
     $self->add_bundle(Filter => {
         bundle => '@Classic',
-        remove => ['PodVersion', ($upload ? () : 'UploadToCPAN')]
+        remove => \@remove
     });
 
     # add FakeRelease plugin if uploads are off
@@ -61,7 +68,7 @@ Dist::Zilla::PluginBundle::MSCHOUT - Use L<Dist::Zilla> like MSCHOUT does
 
 =head1 VERSION
 
-version 0.13
+version 0.14
 
 =head1 DESCRIPTION
 
